@@ -84,6 +84,8 @@ class Analysis(Design, object):
         new_desktop_session,
         close_on_exit,
         student_version,
+        machine="",
+        port=0,
     ):
         self.setups = []
         Design.__init__(
@@ -97,8 +99,9 @@ class Analysis(Design, object):
             new_desktop_session,
             close_on_exit,
             student_version,
+            machine,
+            port,
         )
-
         self.logger.info("Design Loaded")
         self._setup = None
         if setup_name:
@@ -1148,7 +1151,7 @@ class Analysis(Design, object):
         self.analyze_nominal()
 
     @pyaedt_function_handler()
-    def analyze_nominal(self, num_cores=None, num_tasks=None, num_gpu=None, acf_file=None):
+    def analyze_nominal(self, num_cores=None, num_tasks=None, num_gpu=None, acf_file=None, use_auto_settings=True):
         """Solve the nominal design.
 
         Parameters
@@ -1161,6 +1164,8 @@ class Analysis(Design, object):
             Number of simulation graphic processing units to use.
         acf_file : str, optional
             Full path to the custom ACF file.
+        use_auto_settings : bool, optional
+            Either if use or not auto settings in task/cores. It is not supported by all Setup.
 
         Returns
         -------
@@ -1173,7 +1178,7 @@ class Analysis(Design, object):
         >>> oDesign.Analyze
         """
 
-        return self.analyze_setup(self.analysis_setup, num_cores, num_tasks, num_gpu, acf_file)
+        return self.analyze_setup(self.analysis_setup, num_cores, num_tasks, num_gpu, acf_file, use_auto_settings)
 
     @pyaedt_function_handler()
     def generate_unique_setup_name(self, setup_name=None):
@@ -1357,7 +1362,7 @@ class Analysis(Design, object):
         return setup
 
     @pyaedt_function_handler()
-    def create_output_variable(self, variable, expression):
+    def create_output_variable(self, variable, expression, solution=None):
         """Create or modify an output variable.
 
 
@@ -1367,6 +1372,9 @@ class Analysis(Design, object):
             Name of the variable.
         expression :
             Value for the variable.
+        solution :
+            Name of the solution in the format `"setup_name : sweep_name"`.
+            If `None`, the first available solution is used. Default is `None`.
 
         Returns
         -------
@@ -1379,22 +1387,25 @@ class Analysis(Design, object):
         >>> oModule.CreateOutputVariable
         """
         oModule = self.ooutput_variable
+        if solution is None:
+            solution = self.existing_analysis_sweeps[0]
         if variable in self.output_variables:
-            oModule.EditOutputVariable(
-                variable, expression, variable, self.existing_analysis_sweeps[0], self.solution_type, []
-            )
+            oModule.EditOutputVariable(variable, expression, variable, solution, self.solution_type, [])
         else:
-            oModule.CreateOutputVariable(variable, expression, self.existing_analysis_sweeps[0], self.solution_type, [])
+            oModule.CreateOutputVariable(variable, expression, solution, self.solution_type, [])
         return True
 
     @pyaedt_function_handler()
-    def get_output_variable(self, variable):
+    def get_output_variable(self, variable, solution=None):
         """Retrieve the value of the output variable.
 
         Parameters
         ----------
         variable : str
             Name of the variable.
+        solution :
+            Name of the solution in the format `"setup_name : sweep_name"`.
+            If `None`, the first available solution is used. Default is `None`.
 
         Returns
         -------
@@ -1409,10 +1420,11 @@ class Analysis(Design, object):
         """
         assert variable in self.output_variables, "Output variable {} does not exist.".format(variable)
         nominal_variation = self.odesign.GetNominalVariation()
+        if solution is None:
+            solution = self.existing_analysis_sweeps[0]
         value = self.ooutput_variable.GetOutputVariableValue(
-            variable, nominal_variation, self.existing_analysis_sweeps[0], self.solution_type, []
+            variable, nominal_variation, solution, self.solution_type, []
         )
-
         return value
 
     @pyaedt_function_handler()
@@ -1458,7 +1470,7 @@ class Analysis(Design, object):
         return dict
 
     @pyaedt_function_handler()
-    def analyze_setup(self, name, num_cores=None, num_tasks=None, num_gpu=None, acf_file=None):
+    def analyze_setup(self, name, num_cores=None, num_tasks=None, num_gpu=None, acf_file=None, use_auto_settings=True):
         """Analyze a design setup.
 
         Parameters
@@ -1473,6 +1485,8 @@ class Analysis(Design, object):
             Number of simulation graphics processing units. The default is ``None.``
         acf_file : str, optional
             Full path to custom ACF file. The default is ``None.``
+        use_auto_settings : bool, optional
+            Either if use or not auto settings in task/cores. It is not supported by all Setup.
 
         Returns
         -------
@@ -1515,7 +1529,8 @@ class Analysis(Design, object):
             update_hpc_option(target_name, "ConfigName", config_name, True)
             update_hpc_option(target_name, "DesignType", self.design_type, True)
             if self.design_type == "Icepak":
-                update_hpc_option(target_name, "UseAutoSettings", self.design_type, False)
+                use_auto_settings = False
+            update_hpc_option(target_name, "UseAutoSettings", self.design_type, use_auto_settings)
             try:
                 self._desktop.SetRegistryFromFile(target_name)
                 self.set_registry_key(r"Desktop/ActiveDSOConfigurations/" + self.design_type, config_name)
