@@ -70,6 +70,8 @@ class FieldAnalysis3DLayout(Analysis):
         new_desktop_session=False,
         close_on_exit=False,
         student_version=False,
+        machine="",
+        port=0,
     ):
         Analysis.__init__(
             self,
@@ -83,6 +85,8 @@ class FieldAnalysis3DLayout(Analysis):
             new_desktop_session,
             close_on_exit,
             student_version,
+            machine,
+            port,
         )
         self._osolution = self._odesign.GetModule("SolveSetups")
         self._oexcitation = self._odesign.GetModule("Excitations")
