@@ -48,6 +48,8 @@ class AnalysisMaxwellCircuit(Analysis):
         new_desktop_session=False,
         close_on_exit=False,
         student_version=False,
+        machine="",
+        port=0,
     ):
 
         Analysis.__init__(
@@ -62,6 +64,8 @@ class AnalysisMaxwellCircuit(Analysis):
             new_desktop_session,
             close_on_exit,
             student_version,
+            machine,
+            port,
         )
         self.solution_type = None
         self._modeler = ModelerMaxwellCircuit(self)
