@@ -30,6 +30,8 @@ class FieldAnalysisRMxprt(Analysis):
         new_desktop_session=False,
         close_on_exit=False,
         student_version=False,
+        machine="",
+        port=0,
     ):
         Analysis.__init__(
             self,
@@ -43,6 +45,8 @@ class FieldAnalysisRMxprt(Analysis):
             new_desktop_session,
             close_on_exit,
             student_version,
+            machine,
+            port,
         )
 
         self._modeler = ModelerRMxprt(self)
