@@ -45,6 +45,14 @@ class Emit(FieldAnalysisEmit, object):
         Whether to release AEDT on exit. The default is ``True``.
     student_version : bool, optional
         Whether to open the AEDT student version. The default is ``False``.
+    machine : str, optional
+        Machine name to which connect the oDesktop Session. Works only on 2022R2.
+        Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
+        If machine is `"localhost"` the server will also start if not present.
+    port : int, optional
+        Port number of which start the oDesktop communication on already existing server.
+        This parameter is ignored in new server creation. It works only on 2022R2.
+        Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
 
     Examples
     --------
@@ -84,6 +92,8 @@ class Emit(FieldAnalysisEmit, object):
         new_desktop_session=True,
         close_on_exit=True,
         student_version=False,
+        machine="",
+        port=0,
     ):
         """Constructor."""
         FieldAnalysisEmit.__init__(
@@ -98,6 +108,8 @@ class Emit(FieldAnalysisEmit, object):
             new_desktop_session,
             close_on_exit,
             student_version,
+            machine=machine,
+            port=port,
         )
 
     def __enter__(self):
