@@ -3,6 +3,7 @@ import datetime
 import fnmatch
 import inspect
 import itertools
+import json
 import logging
 import os
 import random
@@ -17,7 +18,6 @@ from functools import update_wrapper
 is_ironpython = "IronPython" in sys.version or ".NETFramework" in sys.version
 _pythonver = sys.version_info[0]
 inside_desktop = True
-import sys
 
 try:
     import ScriptEnv
@@ -505,6 +505,18 @@ def is_number(a):
     # return str(a).replace(".", "").replace("+", "").replace("-", "").replace("e","").replace("E","").isnumeric()
 
 
+def is_array(a):
+    try:
+        v = list(eval(a))
+    except (ValueError, TypeError, NameError):
+        return False
+    else:
+        if type(v) is list:
+            return True
+        else:
+            return False
+
+
 def is_project_locked(project_path):
     """Checks if an aedt project lock file exists.
 
@@ -654,6 +666,25 @@ def number_aware_string_key(s):
     return tuple(result)
 
 
+@pyaedt_function_handler()
+def _create_json_file(json_dict, full_json_path):
+    if not is_ironpython:
+        with open(full_json_path, "w") as fp:
+            json.dump(json_dict, fp, indent=4)
+    else:
+        temp_path = full_json_path.replace(".json", "_temp.json")
+        with open(temp_path, "w") as fp:
+            json.dump(json_dict, fp, indent=4)
+        with open(temp_path, "r") as file:
+            filedata = file.read()
+        filedata = filedata.replace("True", "true")
+        filedata = filedata.replace("False", "false")
+        with open(full_json_path, "w") as file:
+            file.write(filedata)
+        os.remove(temp_path)
+    return True
+
+
 class Settings(object):
     """Class that manages all PyAEDT Environment Variables and global settings."""
 
@@ -673,6 +704,25 @@ class Settings(object):
         self._enable_error_handler = True
         self._non_graphical = False
         self.aedt_version = None
+        self.remote_api = False
+        self._use_grpc_api = False
+        self.machine = ""
+        self.port = 0
+
+    @property
+    def use_grpc_api(self):
+        """Set/Get 20222R2 GPRC API usage or Legacy COM Objectr.
+
+        Returns
+        -------
+        bool
+        """
+        return self._use_grpc_api
+
+    @use_grpc_api.setter
+    def use_grpc_api(self, val):
+        """Set/Get 20222R2 GPRC API usage or Legacy COM Objectr."""
+        self._use_grpc_api = val
 
     @property
     def logger(self):
