@@ -421,7 +421,9 @@ def plot_2d_chart(plot_data, size=(2000, 1000), show_legend=True, xlabel="", yla
             label = object[2]
         else:
             label = "Trace " + str(label_id)
-        ax.plot(np.array(object[0]), np.array(object[1]), label=label)
+        x = [i for i, j in zip(object[0], object[1]) if j]
+        y = [i for i in object[1] if i]
+        ax.plot(np.array(x), np.array(y), label=label)
         label_id += 1
 
     ax.set(xlabel=xlabel, ylabel=ylabel, title=title)
@@ -1178,6 +1180,7 @@ class ModelPlotter(object):
                 self.max_elements = (self.startpos - self.endpos) // (self.size + (self.size // 10))
                 self.i = self.max_elements
                 self.axes_color = axes_color
+                self.text = []
 
             def __call__(self, state):
                 self.plot.button_widgets = [self.plot.button_widgets[0]]
@@ -1350,8 +1353,7 @@ class ModelPlotter(object):
                 )
         if self.show_legend:
             self._add_buttons()
-        end = time.time() - start
-        files_list = []
+
         if self.show_axes:
             self.pv.show_axes()
         if self.show_grid and not self.is_notebook:
@@ -1447,8 +1449,7 @@ class ModelPlotter(object):
 
         self.pv.background_color = [i / 255 for i in self.background_color]
         self._read_mesh_files(read_frames=True)
-        end = time.time() - start
-        files_list = []
+
         axes_color = [0 if i >= 128 else 1 for i in self.background_color]
 
         if self.show_axes:
