@@ -51,6 +51,14 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         Whether to release AEDT on exit.
     student_version : bool, optional
         Whether to open the AEDT student version. The default is ``False``.
+    machine : str, optional
+        Machine name to which connect the oDesktop Session. Works only on 2022R2.
+        Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
+        If machine is `"localhost"` the server will also start if not present.
+    port : int, optional
+        Port number of which start the oDesktop communication on already existing server.
+        This parameter is ignored in new server creation. It works only on 2022R2.
+        Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
 
     Examples
     --------
@@ -93,6 +101,8 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         new_desktop_session=False,
         close_on_exit=False,
         student_version=False,
+        machine="",
+        port=0,
     ):
         FieldAnalysis3DLayout.__init__(
             self,
@@ -106,6 +116,8 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             new_desktop_session,
             close_on_exit,
             student_version,
+            machine,
+            port,
         )
 
     def __enter__(self):
