@@ -47,6 +47,14 @@ class Mechanical(FieldAnalysis3D, object):
     student_version : bool, optional
         Whether to open the AEDT student version. The default is ``False``.
         This parameter is ignored when Script is launched within AEDT.
+    machine : str, optional
+        Machine name to which connect the oDesktop Session. Works only on 2022R2.
+        Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
+        If machine is `"localhost"` the server will also start if not present.
+    port : int, optional
+        Port number of which start the oDesktop communication on already existing server.
+        This parameter is ignored in new server creation. It works only on 2022R2.
+        Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
 
     Examples
     --------
@@ -91,6 +99,8 @@ class Mechanical(FieldAnalysis3D, object):
         new_desktop_session=False,
         close_on_exit=False,
         student_version=False,
+        machine="",
+        port=0,
     ):
 
         FieldAnalysis3D.__init__(
@@ -105,6 +115,8 @@ class Mechanical(FieldAnalysis3D, object):
             new_desktop_session,
             close_on_exit,
             student_version,
+            machine,
+            port,
         )
 
     def __enter__(self):
