@@ -2,9 +2,11 @@ import os
 import re
 from warnings import warn
 
+from pyaedt import settings
 from pyaedt.edb import Edb
 from pyaedt.generic.general_methods import _pythonver
 from pyaedt.generic.general_methods import _retry_ntimes
+from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import get_filename_without_extension
 from pyaedt.generic.general_methods import inside_desktop
 from pyaedt.generic.general_methods import is_ironpython
@@ -18,7 +20,6 @@ from pyaedt.modules.LayerStackup import Layers
 
 class Modeler3DLayout(Modeler, Primitives3DLayout):
     """Manages Modeler 3D layouts.
-
     This class is inherited in the caller application and is accessible through the modeler variable
     object (for example, ``hfss3dlayout.modeler``).
 
@@ -81,6 +82,8 @@ class Modeler3DLayout(Modeler, Primitives3DLayout):
              EDB.
 
         """
+        if settings.remote_api:
+            return self._edb
         if not self._edb:
             self._edb = None
             if os.path.exists(self._edb_file) or (inside_desktop and is_ironpython):
@@ -833,3 +836,24 @@ class Modeler3DLayout(Modeler, Primitives3DLayout):
         self.oeditor.UpdateModels(args)
         self.logger.info("Spice Model Correctly assigned to {}.".format(component_name))
         return True
+
+    @pyaedt_function_handler()
+    def clip_plane(self, name=None):
+        """Create a clip plane in Layout.
+
+        .. note::
+            It works only in AEDT from 2022R2.
+
+        Parameters
+        ----------
+        name : str, optional
+            Name of the clip plane.
+
+        Returns
+        -------
+
+        """
+        if not name:
+            name = generate_unique_name("CS")
+        self.oeditor.ClipPlane(name)
+        return name
