@@ -157,6 +157,14 @@ class Rmxprt(FieldAnalysisRMxprt):
         Whether to release AEDT on exit. The default is ``True``.
     student_version : bool, optional
         Whether to open the AEDT student version. The default is ``False``.
+    machine : str, optional
+        Machine name to which connect the oDesktop Session. Works only on 2022R2.
+        Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
+        If machine is `"localhost"` the server will also start if not present.
+    port : int, optional
+        Port number of which start the oDesktop communication on already existing server.
+        This parameter is ignored in new server creation. It works only on 2022R2.
+        Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
 
     Examples
     --------
@@ -195,6 +203,8 @@ class Rmxprt(FieldAnalysisRMxprt):
         new_desktop_session=False,
         close_on_exit=False,
         student_version=False,
+        machine="",
+        port=0,
     ):
         FieldAnalysisRMxprt.__init__(
             self,
@@ -208,6 +218,8 @@ class Rmxprt(FieldAnalysisRMxprt):
             new_desktop_session,
             close_on_exit,
             student_version,
+            machine,
+            port,
         )
         if not model_units or model_units == "mm":
             model_units = "mm"
